==> jc-1.4.0.tar.gz: java/lang/Character__24UnicodeBlock.h <==
// public final class java.lang.Character$UnicodeBlock

// class file dependencies
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 3042a2b418fd11b1 java_lang_Character__24UnicodeBlock
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Character__24Subset

#include "java/lang/Character__24Subset.h"

#ifndef _JC_java_lang_Character__24UnicodeBlock_H_
#define _JC_java_lang_Character__24UnicodeBlock_H_

// Forward structure declarations
struct _jc_java_lang_Character__24UnicodeBlock$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Character__24UnicodeBlock$sub_refs	_jc_java_lang_Character__24UnicodeBlock$sub_refs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs	_jc_java_lang_Character__24UnicodeBlock$sub_nonrefs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$refs	_jc_java_lang_Character__24UnicodeBlock$refs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$nonrefs	_jc_java_lang_Character__24UnicodeBlock$nonrefs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$object	_jc_java_lang_Character__24UnicodeBlock$object;

typedef struct _jc_java_lang_Character__24UnicodeBlock$fields_struct	_jc_java_lang_Character__24UnicodeBlock$fields_struct;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vmethods	_jc_java_lang_Character__24UnicodeBlock$vmethods;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vtable	_jc_java_lang_Character__24UnicodeBlock$vtable;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vtype	_jc_java_lang_Character__24UnicodeBlock$vtype;

// Class fields structure
struct _jc_java_lang_Character__24UnicodeBlock$fields_struct {
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ALPHABETIC__5fPRESENTATION__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC__5fPRESENTATION__5fFORMS__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC__5fPRESENTATION__5fFORMS__5fB;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARMENIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARROWS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BASIC__5fLATIN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BENGALI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BLOCK__5fELEMENTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOPOMOFO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOPOMOFO__5fEXTENDED;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOX__5fDRAWING;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BRAILLE__5fPATTERNS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CHEROKEE;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY__5fIDEOGRAPHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fRADICALS__5fSUPPLEMENT;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fSYMBOLS__5fAND__5fPUNCTUATION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fUNIFIED__5fIDEOGRAPHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fUNIFIED__5fIDEOGRAPHS__5fEXTENSION__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fDIACRITICAL__5fMARKS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fHALF__5fMARKS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fMARKS__5fFOR__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CONTROL__5fPICTURES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CURRENCY__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CYRILLIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*DEVANAGARI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*DINGBATS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ENCLOSED__5fALPHANUMERICS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ENCLOSED__5fCJK__5fLETTERS__5fAND__5fMONTHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ETHIOPIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GENERAL__5fPUNCTUATION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GEOMETRIC__5fSHAPES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GEORGIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GREEK;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GREEK__5fEXTENDED;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GUJARATI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GURMUKHI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HALFWIDTH__5fAND__5fFULLWIDTH__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fCOMPATIBILITY__5fJAMO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fJAMO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fSYLLABLES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HEBREW;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HIRAGANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*IDEOGRAPHIC__5fDESCRIPTION__5fCHARACTERS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*IPA__5fEXTENSIONS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANBUN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANGXI__5fRADICALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANNADA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KATAKANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KHMER;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LAO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5f1__5fSUPPLEMENT;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fADDITIONAL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fB;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LETTERLIKE__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MALAYALAM;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MATHEMATICAL__5fOPERATORS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MISCELLANEOUS__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MISCELLANEOUS__5fTECHNICAL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MONGOLIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MYANMAR;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*NUMBER__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*OGHAM;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*OPTICAL__5fCHARACTER__5fRECOGNITION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ORIYA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*PRIVATE__5fUSE__5fAREA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*RUNIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SINHALA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SMALL__5fFORM__5fVARIANTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SPACING__5fMODIFIER__5fLETTERS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SPECIALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SUPERSCRIPTS__5fAND__5fSUBSCRIPTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SURROGATES__5fAREA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SYRIAC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TAMIL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TELUGU;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*THAANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*THAI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TIBETAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*UNIFIED__5fCANADIAN__5fABORIGINAL__5fSYLLABICS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*YI__5fRADICALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*YI__5fSYLLABLES;
	_jc_object_array	*sets;
};
extern _jc_java_lang_Character__24UnicodeBlock$fields_struct _jc_java_lang_Character__24UnicodeBlock$class_fields;

// Constructors
extern void _jc_java_lang_Character__24UnicodeBlock$method$_init$9c6408b26b3c2192(_jc_env *, struct _jc_java_lang_Character__24UnicodeBlock$object *, jchar, jchar, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_java_lang_Character__24UnicodeBlock$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Character__24UnicodeBlock$object *_jc_java_lang_Character__24UnicodeBlock$method$of$728bd1d193e39802(_jc_env *, jchar);

// Virtual methods structure
struct _jc_java_lang_Character__24UnicodeBlock$vmethods {
};

// Vtable
struct _jc_java_lang_Character__24UnicodeBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
	_jc_java_lang_Character__24UnicodeBlock$vmethods	java_lang_Character__24UnicodeBlock;
};

// Vtype
struct _jc_java_lang_Character__24UnicodeBlock$vtype {
	_jc_type			type;
	_jc_java_lang_Character__24UnicodeBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Character__24UnicodeBlock$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Character__24UnicodeBlock$refs {
    _jc_java_lang_Character__24UnicodeBlock$sub_refs	java_lang_Character__24UnicodeBlock;
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs {
	jchar	start;
	jchar	end;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Character__24UnicodeBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
    _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs	java_lang_Character__24UnicodeBlock;
};

// Object instance structure
struct _jc_java_lang_Character__24UnicodeBlock$object {
	_jc_java_lang_Character__24UnicodeBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Character__24UnicodeBlock$vtype	*vtype;
	_jc_java_lang_Character__24UnicodeBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Character__24UnicodeBlock$vtype _jc_java_lang_Character__24UnicodeBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Character__24UnicodeBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Character__24UnicodeBlock$class_object;

#endif	/* _JC_java_lang_Character__24UnicodeBlock_H_ */

==> jc-1.4.6.tar.gz: java/lang/Character__24UnicodeBlock.h <==
// public final class java.lang.Character$UnicodeBlock

// class file dependencies
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 3042a2b418fd11b1 java_lang_Character__24UnicodeBlock
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Character__24Subset

#include "java/lang/Character__24Subset.h"

#ifndef _JC_java_lang_Character__24UnicodeBlock_H_
#define _JC_java_lang_Character__24UnicodeBlock_H_

// Forward structure declarations
struct _jc_java_lang_Character__24UnicodeBlock$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Character__24UnicodeBlock$sub_refs	_jc_java_lang_Character__24UnicodeBlock$sub_refs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs	_jc_java_lang_Character__24UnicodeBlock$sub_nonrefs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$refs	_jc_java_lang_Character__24UnicodeBlock$refs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$nonrefs	_jc_java_lang_Character__24UnicodeBlock$nonrefs;
typedef struct _jc_java_lang_Character__24UnicodeBlock$object	_jc_java_lang_Character__24UnicodeBlock$object;

typedef struct _jc_java_lang_Character__24UnicodeBlock$fields_struct	_jc_java_lang_Character__24UnicodeBlock$fields_struct;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vmethods	_jc_java_lang_Character__24UnicodeBlock$vmethods;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vtable	_jc_java_lang_Character__24UnicodeBlock$vtable;
typedef const struct _jc_java_lang_Character__24UnicodeBlock$vtype	_jc_java_lang_Character__24UnicodeBlock$vtype;

// Class fields structure
struct _jc_java_lang_Character__24UnicodeBlock$fields_struct {
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ALPHABETIC__5fPRESENTATION__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC__5fPRESENTATION__5fFORMS__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARABIC__5fPRESENTATION__5fFORMS__5fB;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARMENIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ARROWS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BASIC__5fLATIN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BENGALI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BLOCK__5fELEMENTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOPOMOFO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOPOMOFO__5fEXTENDED;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BOX__5fDRAWING;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*BRAILLE__5fPATTERNS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CHEROKEE;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fCOMPATIBILITY__5fIDEOGRAPHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fRADICALS__5fSUPPLEMENT;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fSYMBOLS__5fAND__5fPUNCTUATION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fUNIFIED__5fIDEOGRAPHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CJK__5fUNIFIED__5fIDEOGRAPHS__5fEXTENSION__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fDIACRITICAL__5fMARKS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fHALF__5fMARKS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*COMBINING__5fMARKS__5fFOR__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CONTROL__5fPICTURES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CURRENCY__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*CYRILLIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*DEVANAGARI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*DINGBATS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ENCLOSED__5fALPHANUMERICS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ENCLOSED__5fCJK__5fLETTERS__5fAND__5fMONTHS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ETHIOPIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GENERAL__5fPUNCTUATION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GEOMETRIC__5fSHAPES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GEORGIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GREEK;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GREEK__5fEXTENDED;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GUJARATI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*GURMUKHI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HALFWIDTH__5fAND__5fFULLWIDTH__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fCOMPATIBILITY__5fJAMO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fJAMO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HANGUL__5fSYLLABLES;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HEBREW;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*HIRAGANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*IDEOGRAPHIC__5fDESCRIPTION__5fCHARACTERS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*IPA__5fEXTENSIONS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANBUN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANGXI__5fRADICALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KANNADA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KATAKANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*KHMER;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LAO;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5f1__5fSUPPLEMENT;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fADDITIONAL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LATIN__5fEXTENDED__5fB;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*LETTERLIKE__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MALAYALAM;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MATHEMATICAL__5fOPERATORS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MISCELLANEOUS__5fSYMBOLS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MISCELLANEOUS__5fTECHNICAL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MONGOLIAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*MYANMAR;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*NUMBER__5fFORMS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*OGHAM;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*OPTICAL__5fCHARACTER__5fRECOGNITION;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*ORIYA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*PRIVATE__5fUSE__5fAREA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*RUNIC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SINHALA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SMALL__5fFORM__5fVARIANTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SPACING__5fMODIFIER__5fLETTERS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SPECIALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SUPERSCRIPTS__5fAND__5fSUBSCRIPTS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SURROGATES__5fAREA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*SYRIAC;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TAMIL;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TELUGU;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*THAANA;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*THAI;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*TIBETAN;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*UNIFIED__5fCANADIAN__5fABORIGINAL__5fSYLLABICS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*YI__5fRADICALS;
	struct _jc_java_lang_Character__24UnicodeBlock$object	*YI__5fSYLLABLES;
	_jc_object_array	*sets;
};
extern _jc_java_lang_Character__24UnicodeBlock$fields_struct _jc_java_lang_Character__24UnicodeBlock$class_fields;

// Constructors
extern void _jc_java_lang_Character__24UnicodeBlock$method$_init$9c6408b26b3c2192(_jc_env *, struct _jc_java_lang_Character__24UnicodeBlock$object *, jchar, jchar, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_Character__24UnicodeBlock$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Character__24UnicodeBlock$object *_jc_java_lang_Character__24UnicodeBlock$method$of$728bd1d193e39802(_jc_env *, jchar) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Character__24UnicodeBlock$vmethods {
};

// Vtable
struct _jc_java_lang_Character__24UnicodeBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
	_jc_java_lang_Character__24UnicodeBlock$vmethods	java_lang_Character__24UnicodeBlock;
};

// Vtype
struct _jc_java_lang_Character__24UnicodeBlock$vtype {
	_jc_type			type;
	_jc_java_lang_Character__24UnicodeBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Character__24UnicodeBlock$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Character__24UnicodeBlock$refs {
    _jc_java_lang_Character__24UnicodeBlock$sub_refs	java_lang_Character__24UnicodeBlock;
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs {
	jchar	start;
	jchar	end;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Character__24UnicodeBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
    _jc_java_lang_Character__24UnicodeBlock$sub_nonrefs	java_lang_Character__24UnicodeBlock;
};

// Object instance structure
struct _jc_java_lang_Character__24UnicodeBlock$object {
	_jc_java_lang_Character__24UnicodeBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Character__24UnicodeBlock$vtype	*vtype;
	_jc_java_lang_Character__24UnicodeBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Character__24UnicodeBlock$vtype _jc_java_lang_Character__24UnicodeBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Character__24UnicodeBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Character__24UnicodeBlock$class_object;

#endif	/* _JC_java_lang_Character__24UnicodeBlock_H_ */
